@@ -36,12 +36,22 @@
 static int N_X11=0;
 static g2_X11_device *g2_X11_dev=NULL;
 
+/**
+ * \ingroup interface
+ * \defgroup X11 X11
+ */
+
 
 /**
- **
- ** Attach (simple) X11 device
- **
- **/
+ *
+ * Open a simple X11 window (physical device device).
+ *
+ * \param width window width
+ * \param height window height
+ * \return physical device id
+ *
+ * \ingroup X11
+ */
 int g2_open_X11(int width, int height)
 {
     return g2_open_X11X(width, height,
@@ -53,10 +63,25 @@ int g2_open_X11(int width, int height)
 
 
 /**
- **
- ** Attach (extended) X11 device
- **
- **/
+ *
+ * Open a X11 window (physical device device). If \a icon_width or \a
+ * icon_height is smaller than 0, the \a icon_data is interpreted as a
+ * file name.
+ *
+ * \param width window width
+ * \param height window height
+ * \param x x position on screen
+ * \param y y position on screen
+ * \param window_name hint for window manager
+ * \param icon_name hint for window manager
+ * \param icon_data icon bitmap (\a icon_width * \a icon_height bits) or file name containing bitmap
+ *                  (if \a icon_width <= 0 or \a icon_height <= 0) 
+ * \param icon_width icon width
+ * \param icon_height icon height
+ * \return physical device id
+ *
+ * \ingroup X11
+ */
 int g2_open_X11X(int width, int height,
 		 int x, int y,
 		 char *window_name, char *icon_name,
@@ -144,7 +169,7 @@ int g2_X11_init_X11X(int pid, int width, int height,
     XClassHint class_hint;
 
     if((xout->display=XOpenDisplay(NULL))==NULL) { 
-	fputs("g2: can not open display\n", stderr);
+	g2_log(Error, "g2: can't open display\n");
 	exit(-1);
     }
 
@@ -265,19 +290,23 @@ int g2_X11_init_X11X(int pid, int width, int height,
     xout->backing_pixmap = None;
 
     if(XDoesBackingStore(XDefaultScreenOfDisplay(xout->display))!=Always) {
-	/* fputs("g2: Warning! Backing store is not available.Allocating pixmap instead.\n", stderr); */
-	
-	xout->backing_pixmap = XCreatePixmap(xout->display, xout->window,
-					     xout->width, xout->height,
-					     DefaultDepth(xout->display, DefaultScreen(xout->display)));
-	XSetWindowBackgroundPixmap(xout->display, xout->window,
-				   xout->backing_pixmap);
+	if(g2_EmulateBackingStore) {
+	    g2_log(Warning, "g2: Warning! Backing store is not available. Allocating pixmap instead.\n");
+
+	    xout->backing_pixmap = XCreatePixmap(xout->display, xout->window,
+						 xout->width, xout->height,
+						 DefaultDepth(xout->display, DefaultScreen(xout->display)));
+	    XSetWindowBackgroundPixmap(xout->display, xout->window,
+				       xout->backing_pixmap);
 	  
-	XSetForeground (xout->display, xout->gc, w_scr.pixel);
+	    XSetForeground (xout->display, xout->gc, w_scr.pixel);
           
-	XFillRectangle(xout->display, xout->backing_pixmap, xout->gc,
-		       0, 0, xout->width, xout->height);
-	xout->dest = xout->backing_pixmap;
+	    XFillRectangle(xout->display, xout->backing_pixmap, xout->gc,
+			   0, 0, xout->width, xout->height);
+	    xout->dest = xout->backing_pixmap;
+	} else {
+		g2_log(Warning, "g2: Warning! Backing store is not available.\n");
+	}
     }
 
     XFlush(xout->display);
@@ -311,18 +340,15 @@ int g2_X11_clear(int pid, void *pdp)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
     
-    if (xout->backing_pixmap == None)
-      {
-      XClearWindow(xout->display,xout->window);
-      }
-    else
-      {
-      XSetForeground (xout->display, xout->gc,
-                  xout->background);
-      XFillRectangle(xout->display, xout->dest, xout->gc,
-                 0, 0, xout->width, xout->height);
-      }
-    g2_X11_flush(pid,pdp);
+    if (xout->backing_pixmap == None) {
+	XClearWindow(xout->display,xout->window);
+    } else {
+	XSetForeground (xout->display, xout->gc,
+			xout->background);
+	XFillRectangle(xout->display, xout->dest, xout->gc,
+		       0, 0, xout->width, xout->height);
+    }
+    g2_X11_flush(pid, pdp);
     return 0;
 }
 
@@ -332,9 +358,9 @@ int g2_X11_flush(int pid, void *pdp)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
     if( xout->backing_pixmap != None ) {
-      XCopyArea(xout->display, xout->dest, xout->window, xout->gc,
-              0, 0, xout->width, xout->height, 0, 0);
-      }
+	XCopyArea(xout->display, xout->dest, xout->window, xout->gc,
+		  0, 0, xout->width, xout->height, 0, 0);
+    }
     XFlush(xout->display);
     return 0;
 }
@@ -477,7 +503,7 @@ int g2_X11_set_font_size(int pid, void *pdp, int size)
     
     for(n=1;n<32;n++) {
 	d=((n&0x01)? -1:1)*(n>>1);
-	sprintf(font_name, G2_X11_FONT, sizei+d);
+	sprintf(font_name, g2_X11Font, sizei+d);
 	fnt_str=XLoadQueryFont(xout->display, font_name);
 	if(fnt_str==NULL) {
 	    if(!d)
